/*
 * Copyright 2016 - 2025 Gary Talent (gary@drinkingtea.net). All rights reserved.
 */

#pragma once

#include <ox/std/memory.hpp>
#include <ox/std/string.hpp>

#include <turbine/context.hpp>

namespace studio {

class ProjectTreeModel {
	private:
		class ProjectExplorer &m_explorer;
		ProjectTreeModel *m_parent = nullptr;
		ox::String m_name;
		ox::Vector<ox::UPtr<ProjectTreeModel>> m_children;

	public:
		explicit ProjectTreeModel(
			ProjectExplorer &explorer, ox::StringParam name,
			ProjectTreeModel *parent = nullptr) noexcept;

		ProjectTreeModel(ProjectTreeModel &&other) noexcept;

		void draw(turbine::Context &tctx) const noexcept;

		void setChildren(ox::Vector<ox::UPtr<ProjectTreeModel>> children) noexcept;

	private:
		void drawDirContextMenu() const noexcept;

		template<typename Str = ox::BasicString<255>>
		[[nodiscard]]
		Str fullPath() const noexcept {
			if (m_parent) {
				return m_parent->fullPath<Str>() + "/" + m_name;
			}
			return {};
		}

};

}
